@@ -1,5 +1,5 @@
-use crate::{synthesis::mh::rayon::prelude::*, Point};
-use std::{f64::consts::TAU, marker::PhantomData};
+use crate::Point;
+use std::marker::PhantomData;
 
 /// Mechanism position formula.
 #[allow(missing_docs)]
@@ -82,6 +82,7 @@ impl<L: Linkage> Mechanism<L> {
 
     /// Get the trajectory by parallel computing.
     pub fn par_curve(&self, start: f64, end: f64, n: usize) -> Vec<[f64; 2]> {
+        use crate::mh::rayon::prelude::*;
         let interval = (end - start) / n as f64;
         (0..n)
             .into_par_iter()
@@ -95,8 +96,8 @@ impl<L: Linkage> Mechanism<L> {
     }
 
     /// A loop trajectory for all moving pivot.
-    pub fn curve_all(&self, start: f64, n: usize) -> [Vec<[f64; 2]>; 3] {
-        let interval = TAU / n as f64;
+    pub fn curve_all(&self, start: f64, end: f64, n: usize) -> [Vec<[f64; 2]>; 3] {
+        let interval = (end - start) / n as f64;
         let mut path = [vec![[0.; 2]; n], vec![[0.; 2]; n], vec![[0.; 2]; n]];
         for i in 0..n {
             let a = start + i as f64 * interval;
@@ -108,4 +109,9 @@ impl<L: Linkage> Mechanism<L> {
         }
         path
     }
+
+    /// Calculate the formula, and write the answer into provided array.
+    pub fn apply<const N: usize>(&self, angle: f64, joint: [usize; N], ans: &mut [[f64; 2]; N]) {
+        L::apply(self, angle, joint, ans)
+    }
 }
